import * as d3 from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;
  const margin = 0;

  // main circle
  const cx = width / 2;
  const cy = height / 2;
  const R = 20;

  // little circles
  const r = 2;

  // degree - radian conversion
  function radian(degree) {
    return (degree * Math.PI) / 180;
  }

  // parametric equation of a circle is : x=cx+r*cos(t) and y=cy+r*sin(t)
  function x(radian) {
    return cx + R * Math.cos(radian);
  }
  function y(radian) {
    return cy + R * Math.sin(radian);
  }

  const svg = d3
    .select(container)
    .append('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background-color', 'lightblue')
    .append('g')
    .attr(
      'transform',
      'translate(' + margin + ',' + margin + ')',
    );

  // little circles
  // 10 equal sectors for 10 points on the main circle
  const SECTORS = 10; // number of sectors
  const SECTOR = 360 / SECTORS; // sector in degree: each equal
  let anglesList = [];

  for (let index = 0; index < SECTORS; index++) {
    anglesList.push(radian(index * SECTOR));
  }
  const MAX = anglesList[SECTORS - 1];

  // opacity
  function getOpacity(datum) {
    return Number((datum / MAX).toFixed(1));
  }

  // little circle radius
  function getRadius(datum) {
    return Number(r + r * (datum / MAX).toFixed(1));
  }

  function update(dataset) {
    let littleCircle = svg
      .selectAll('#little')
      .data(dataset);

    // UPDATE
    // Update old elements as needed.
    littleCircle
      .attr('r', function (d) {
        return getRadius(d);
      })
      .style('opacity', function (d) {
        return getOpacity(d);
      });

    // ENTER
    // Create new elements as needed.
    littleCircle
      .enter()
      .append('circle')
      .attr('id', 'little')
      .attr('fill', 'blue')
      .attr('cx', function (d) {
        return x(d);
      })
      .attr('cy', function (d) {
        return y(d);
      })
      .attr('r', function (d) {
        return getRadius(d);
      })
      .style('opacity', function (d) {
        return getOpacity(d);
      });

    // EXIT
    // Remove old elements as needed.
    // littleCircle.exit().remove();
  }

  update(anglesList);

  function arrayRotate(arr, count) {
    count -= arr.length * Math.floor(count / arr.length);
    arr.push.apply(arr, arr.splice(0, count));
    return arr;
  }

  // cyclic circular permutation
  d3.interval(function () {
    anglesList = arrayRotate(anglesList.slice(), -1);
    update(anglesList);
  }, 150);
};
